Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ResolveConfigPath ¶ added in v1.0.22
ResolveConfigPath returns the path to an existing config file in dir, trying each accepted extension in priority order. If none exist it returns the canonical (.yaml) path so new files are created canonically.
Types ¶
type Output ¶
func ResolveValue ¶
Click to show internal directories.
Click to hide internal directories.