package
Version:
v1.0.19
Opens a new window with list of versions in this module.
Published: Jun 28, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
const (
ContextPipeline Kind = "pipeline"
ContextServer Kind = "server"
ContextRepository Kind = "repository"
ContextGlobal Kind = "global"
)
type LoadResult struct {
LoadedPaths []string
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.